@@ -8,6 +8,10 @@ class JsonEncoder(json.JSONEncoder):
     def default(self, obj: Any) -> Any:
         if isinstance(obj, Status):
             return obj.__dict__
+        elif isinstance(obj, JointAngles):
+            return obj.__dict__
+        elif isinstance(obj, GripperPosition):
+            return obj.__dict__
         elif isinstance(obj, Vector3):
             return obj.__dict__
         elif isinstance(obj, Pose):
@@ -48,6 +52,10 @@ class JsonDecoder(json.JSONDecoder):
     @staticmethod
     def dict_to_object(obj):
         if isinstance(obj, dict):
+            if '_type' in obj and obj['_type'] == 'joint_angles':
+                return JointAngles(**obj)
+            if '_type' in obj and obj['_type'] == 'gripper_position':
+                return GripperPosition(**obj)
             if '_type' in obj and obj['_type'] == 'status':
                 return Status(**obj)
             if '_type' in obj and obj['_type'] == 'vector3':
